==> vtk-8.1.0-6-arm.pkg.tar.xz: vtk/vtkLineIntegralConvolution2D.java <==
// java wrapper for vtkLineIntegralConvolution2D object
//

package vtk;
import vtk.*;

public class vtkLineIntegralConvolution2D extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean IsSupported_2(vtkRenderWindow id0);
  public boolean IsSupported(vtkRenderWindow id0)
    { return IsSupported_2(id0); }

  private native void SetContext_3(vtkOpenGLRenderWindow id0);
  public void SetContext(vtkOpenGLRenderWindow id0)
    { SetContext_3(id0); }

  private native long GetContext_4();
  public vtkOpenGLRenderWindow GetContext() {
    long temp = GetContext_4();

    if (temp == 0) return null;
    return (vtkOpenGLRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetEnhancedLIC_5(int id0);
  public void SetEnhancedLIC(int id0)
    { SetEnhancedLIC_5(id0); }

  private native int GetEnhancedLICMinValue_6();
  public int GetEnhancedLICMinValue()
    { return GetEnhancedLICMinValue_6(); }

  private native int GetEnhancedLICMaxValue_7();
  public int GetEnhancedLICMaxValue()
    { return GetEnhancedLICMaxValue_7(); }

  private native int GetEnhancedLIC_8();
  public int GetEnhancedLIC()
    { return GetEnhancedLIC_8(); }

  private native void EnhancedLICOn_9();
  public void EnhancedLICOn()
    { EnhancedLICOn_9(); }

  private native void EnhancedLICOff_10();
  public void EnhancedLICOff()
    { EnhancedLICOff_10(); }

  private native void SetEnhanceContrast_11(int id0);
  public void SetEnhanceContrast(int id0)
    { SetEnhanceContrast_11(id0); }

  private native int GetEnhanceContrastMinValue_12();
  public int GetEnhanceContrastMinValue()
    { return GetEnhanceContrastMinValue_12(); }

  private native int GetEnhanceContrastMaxValue_13();
  public int GetEnhanceContrastMaxValue()
    { return GetEnhanceContrastMaxValue_13(); }

  private native int GetEnhanceContrast_14();
  public int GetEnhanceContrast()
    { return GetEnhanceContrast_14(); }

  private native void EnhanceContrastOn_15();
  public void EnhanceContrastOn()
    { EnhanceContrastOn_15(); }

  private native void EnhanceContrastOff_16();
  public void EnhanceContrastOff()
    { EnhanceContrastOff_16(); }

  private native void SetLowContrastEnhancementFactor_17(double id0);
  public void SetLowContrastEnhancementFactor(double id0)
    { SetLowContrastEnhancementFactor_17(id0); }

  private native double GetLowContrastEnhancementFactorMinValue_18();
  public double GetLowContrastEnhancementFactorMinValue()
    { return GetLowContrastEnhancementFactorMinValue_18(); }

  private native double GetLowContrastEnhancementFactorMaxValue_19();
  public double GetLowContrastEnhancementFactorMaxValue()
    { return GetLowContrastEnhancementFactorMaxValue_19(); }

  private native double GetLowContrastEnhancementFactor_20();
  public double GetLowContrastEnhancementFactor()
    { return GetLowContrastEnhancementFactor_20(); }

  private native void SetHighContrastEnhancementFactor_21(double id0);
  public void SetHighContrastEnhancementFactor(double id0)
    { SetHighContrastEnhancementFactor_21(id0); }

  private native double GetHighContrastEnhancementFactorMinValue_22();
  public double GetHighContrastEnhancementFactorMinValue()
    { return GetHighContrastEnhancementFactorMinValue_22(); }

  private native double GetHighContrastEnhancementFactorMaxValue_23();
  public double GetHighContrastEnhancementFactorMaxValue()
    { return GetHighContrastEnhancementFactorMaxValue_23(); }

  private native double GetHighContrastEnhancementFactor_24();
  public double GetHighContrastEnhancementFactor()
    { return GetHighContrastEnhancementFactor_24(); }

  private native void SetAntiAlias_25(int id0);
  public void SetAntiAlias(int id0)
    { SetAntiAlias_25(id0); }

  private native int GetAntiAliasMinValue_26();
  public int GetAntiAliasMinValue()
    { return GetAntiAliasMinValue_26(); }

  private native int GetAntiAliasMaxValue_27();
  public int GetAntiAliasMaxValue()
    { return GetAntiAliasMaxValue_27(); }

  private native int GetAntiAlias_28();
  public int GetAntiAlias()
    { return GetAntiAlias_28(); }

  private native void AntiAliasOn_29();
  public void AntiAliasOn()
    { AntiAliasOn_29(); }

  private native void AntiAliasOff_30();
  public void AntiAliasOff()
    { AntiAliasOff_30(); }

  private native void SetNumberOfSteps_31(int id0);
  public void SetNumberOfSteps(int id0)
    { SetNumberOfSteps_31(id0); }

  private native int GetNumberOfStepsMinValue_32();
  public int GetNumberOfStepsMinValue()
    { return GetNumberOfStepsMinValue_32(); }

  private native int GetNumberOfStepsMaxValue_33();
  public int GetNumberOfStepsMaxValue()
    { return GetNumberOfStepsMaxValue_33(); }

  private native int GetNumberOfSteps_34();
  public int GetNumberOfSteps()
    { return GetNumberOfSteps_34(); }

  private native void SetStepSize_35(double id0);
  public void SetStepSize(double id0)
    { SetStepSize_35(id0); }

  private native double GetStepSizeMinValue_36();
  public double GetStepSizeMinValue()
    { return GetStepSizeMinValue_36(); }

  private native double GetStepSizeMaxValue_37();
  public double GetStepSizeMaxValue()
    { return GetStepSizeMaxValue_37(); }

  private native double GetStepSize_38();
  public double GetStepSize()
    { return GetStepSize_38(); }

  private native void SetComponentIds_39(int id0,int id1);
  public void SetComponentIds(int id0,int id1)
    { SetComponentIds_39(id0,id1); }

  private native void SetComponentIds_40(int id0[]);
  public void SetComponentIds(int id0[])
    { SetComponentIds_40(id0); }

  private native int[]  GetComponentIds_41();
  public int[]  GetComponentIds()
    { return GetComponentIds_41(); }

  private native void SetMaxNoiseValue_42(double id0);
  public void SetMaxNoiseValue(double id0)
    { SetMaxNoiseValue_42(id0); }

  private native double GetMaxNoiseValueMinValue_43();
  public double GetMaxNoiseValueMinValue()
    { return GetMaxNoiseValueMinValue_43(); }

  private native double GetMaxNoiseValueMaxValue_44();
  public double GetMaxNoiseValueMaxValue()
    { return GetMaxNoiseValueMaxValue_44(); }

  private native double GetMaxNoiseValue_45();
  public double GetMaxNoiseValue()
    { return GetMaxNoiseValue_45(); }

  private native void SetTransformVectors_46(int id0);
  public void SetTransformVectors(int id0)
    { SetTransformVectors_46(id0); }

  private native int GetTransformVectors_47();
  public int GetTransformVectors()
    { return GetTransformVectors_47(); }

  private native void SetNormalizeVectors_48(int id0);
  public void SetNormalizeVectors(int id0)
    { SetNormalizeVectors_48(id0); }

  private native int GetNormalizeVectors_49();
  public int GetNormalizeVectors()
    { return GetNormalizeVectors_49(); }

  private native void SetMaskThreshold_50(double id0);
  public void SetMaskThreshold(double id0)
    { SetMaskThreshold_50(id0); }

  private native double GetMaskThresholdMinValue_51();
  public double GetMaskThresholdMinValue()
    { return GetMaskThresholdMinValue_51(); }

  private native double GetMaskThresholdMaxValue_52();
  public double GetMaskThresholdMaxValue()
    { return GetMaskThresholdMaxValue_52(); }

  private native double GetMaskThreshold_53();
  public double GetMaskThreshold()
    { return GetMaskThreshold_53(); }

  private native void WriteTimerLog_54(String id0);
  public void WriteTimerLog(String id0)
    { WriteTimerLog_54(id0); }

  public vtkLineIntegralConvolution2D() { super(); }

  public vtkLineIntegralConvolution2D(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-arm.pkg.tar.xz: vtk/vtkLineIntegralConvolution2D.java <==
// java wrapper for vtkLineIntegralConvolution2D object
//

package vtk;
import vtk.*;

public class vtkLineIntegralConvolution2D extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean IsSupported_2(vtkRenderWindow id0);
  public boolean IsSupported(vtkRenderWindow id0)
    { return IsSupported_2(id0); }

  private native void SetContext_3(vtkOpenGLRenderWindow id0);
  public void SetContext(vtkOpenGLRenderWindow id0)
    { SetContext_3(id0); }

  private native long GetContext_4();
  public vtkOpenGLRenderWindow GetContext() {
    long temp = GetContext_4();

    if (temp == 0) return null;
    return (vtkOpenGLRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetEnhancedLIC_5(int id0);
  public void SetEnhancedLIC(int id0)
    { SetEnhancedLIC_5(id0); }

  private native int GetEnhancedLICMinValue_6();
  public int GetEnhancedLICMinValue()
    { return GetEnhancedLICMinValue_6(); }

  private native int GetEnhancedLICMaxValue_7();
  public int GetEnhancedLICMaxValue()
    { return GetEnhancedLICMaxValue_7(); }

  private native int GetEnhancedLIC_8();
  public int GetEnhancedLIC()
    { return GetEnhancedLIC_8(); }

  private native void EnhancedLICOn_9();
  public void EnhancedLICOn()
    { EnhancedLICOn_9(); }

  private native void EnhancedLICOff_10();
  public void EnhancedLICOff()
    { EnhancedLICOff_10(); }

  private native void SetEnhanceContrast_11(int id0);
  public void SetEnhanceContrast(int id0)
    { SetEnhanceContrast_11(id0); }

  private native int GetEnhanceContrastMinValue_12();
  public int GetEnhanceContrastMinValue()
    { return GetEnhanceContrastMinValue_12(); }

  private native int GetEnhanceContrastMaxValue_13();
  public int GetEnhanceContrastMaxValue()
    { return GetEnhanceContrastMaxValue_13(); }

  private native int GetEnhanceContrast_14();
  public int GetEnhanceContrast()
    { return GetEnhanceContrast_14(); }

  private native void EnhanceContrastOn_15();
  public void EnhanceContrastOn()
    { EnhanceContrastOn_15(); }

  private native void EnhanceContrastOff_16();
  public void EnhanceContrastOff()
    { EnhanceContrastOff_16(); }

  private native void SetLowContrastEnhancementFactor_17(double id0);
  public void SetLowContrastEnhancementFactor(double id0)
    { SetLowContrastEnhancementFactor_17(id0); }

  private native double GetLowContrastEnhancementFactorMinValue_18();
  public double GetLowContrastEnhancementFactorMinValue()
    { return GetLowContrastEnhancementFactorMinValue_18(); }

  private native double GetLowContrastEnhancementFactorMaxValue_19();
  public double GetLowContrastEnhancementFactorMaxValue()
    { return GetLowContrastEnhancementFactorMaxValue_19(); }

  private native double GetLowContrastEnhancementFactor_20();
  public double GetLowContrastEnhancementFactor()
    { return GetLowContrastEnhancementFactor_20(); }

  private native void SetHighContrastEnhancementFactor_21(double id0);
  public void SetHighContrastEnhancementFactor(double id0)
    { SetHighContrastEnhancementFactor_21(id0); }

  private native double GetHighContrastEnhancementFactorMinValue_22();
  public double GetHighContrastEnhancementFactorMinValue()
    { return GetHighContrastEnhancementFactorMinValue_22(); }

  private native double GetHighContrastEnhancementFactorMaxValue_23();
  public double GetHighContrastEnhancementFactorMaxValue()
    { return GetHighContrastEnhancementFactorMaxValue_23(); }

  private native double GetHighContrastEnhancementFactor_24();
  public double GetHighContrastEnhancementFactor()
    { return GetHighContrastEnhancementFactor_24(); }

  private native void SetAntiAlias_25(int id0);
  public void SetAntiAlias(int id0)
    { SetAntiAlias_25(id0); }

  private native int GetAntiAliasMinValue_26();
  public int GetAntiAliasMinValue()
    { return GetAntiAliasMinValue_26(); }

  private native int GetAntiAliasMaxValue_27();
  public int GetAntiAliasMaxValue()
    { return GetAntiAliasMaxValue_27(); }

  private native int GetAntiAlias_28();
  public int GetAntiAlias()
    { return GetAntiAlias_28(); }

  private native void AntiAliasOn_29();
  public void AntiAliasOn()
    { AntiAliasOn_29(); }

  private native void AntiAliasOff_30();
  public void AntiAliasOff()
    { AntiAliasOff_30(); }

  private native void SetNumberOfSteps_31(int id0);
  public void SetNumberOfSteps(int id0)
    { SetNumberOfSteps_31(id0); }

  private native int GetNumberOfStepsMinValue_32();
  public int GetNumberOfStepsMinValue()
    { return GetNumberOfStepsMinValue_32(); }

  private native int GetNumberOfStepsMaxValue_33();
  public int GetNumberOfStepsMaxValue()
    { return GetNumberOfStepsMaxValue_33(); }

  private native int GetNumberOfSteps_34();
  public int GetNumberOfSteps()
    { return GetNumberOfSteps_34(); }

  private native void SetStepSize_35(double id0);
  public void SetStepSize(double id0)
    { SetStepSize_35(id0); }

  private native double GetStepSizeMinValue_36();
  public double GetStepSizeMinValue()
    { return GetStepSizeMinValue_36(); }

  private native double GetStepSizeMaxValue_37();
  public double GetStepSizeMaxValue()
    { return GetStepSizeMaxValue_37(); }

  private native double GetStepSize_38();
  public double GetStepSize()
    { return GetStepSize_38(); }

  private native void SetComponentIds_39(int id0,int id1);
  public void SetComponentIds(int id0,int id1)
    { SetComponentIds_39(id0,id1); }

  private native void SetComponentIds_40(int id0[]);
  public void SetComponentIds(int id0[])
    { SetComponentIds_40(id0); }

  private native int[]  GetComponentIds_41();
  public int[]  GetComponentIds()
    { return GetComponentIds_41(); }

  private native void SetMaxNoiseValue_42(double id0);
  public void SetMaxNoiseValue(double id0)
    { SetMaxNoiseValue_42(id0); }

  private native double GetMaxNoiseValueMinValue_43();
  public double GetMaxNoiseValueMinValue()
    { return GetMaxNoiseValueMinValue_43(); }

  private native double GetMaxNoiseValueMaxValue_44();
  public double GetMaxNoiseValueMaxValue()
    { return GetMaxNoiseValueMaxValue_44(); }

  private native double GetMaxNoiseValue_45();
  public double GetMaxNoiseValue()
    { return GetMaxNoiseValue_45(); }

  private native void SetTransformVectors_46(int id0);
  public void SetTransformVectors(int id0)
    { SetTransformVectors_46(id0); }

  private native int GetTransformVectors_47();
  public int GetTransformVectors()
    { return GetTransformVectors_47(); }

  private native void SetNormalizeVectors_48(int id0);
  public void SetNormalizeVectors(int id0)
    { SetNormalizeVectors_48(id0); }

  private native int GetNormalizeVectors_49();
  public int GetNormalizeVectors()
    { return GetNormalizeVectors_49(); }

  private native void SetMaskThreshold_50(double id0);
  public void SetMaskThreshold(double id0)
    { SetMaskThreshold_50(id0); }

  private native double GetMaskThresholdMinValue_51();
  public double GetMaskThresholdMinValue()
    { return GetMaskThresholdMinValue_51(); }

  private native double GetMaskThresholdMaxValue_52();
  public double GetMaskThresholdMaxValue()
    { return GetMaskThresholdMaxValue_52(); }

  private native double GetMaskThreshold_53();
  public double GetMaskThreshold()
    { return GetMaskThreshold_53(); }

  private native long Execute_54(vtkTextureObject id0,vtkTextureObject id1);
  public vtkTextureObject Execute(vtkTextureObject id0,vtkTextureObject id1) {
    long temp = Execute_54(id0,id1);

    if (temp == 0) return null;
    return (vtkTextureObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long Execute_55(int id0[],vtkTextureObject id1,vtkTextureObject id2);
  public vtkTextureObject Execute(int id0[],vtkTextureObject id1,vtkTextureObject id2) {
    long temp = Execute_55(id0,id1,id2);

    if (temp == 0) return null;
    return (vtkTextureObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetVectorTexParameters_56(vtkTextureObject id0);
  public void SetVectorTexParameters(vtkTextureObject id0)
    { SetVectorTexParameters_56(id0); }

  private native void SetNoiseTexParameters_57(vtkTextureObject id0);
  public void SetNoiseTexParameters(vtkTextureObject id0)
    { SetNoiseTexParameters_57(id0); }

  private native void WriteTimerLog_58(String id0);
  public void WriteTimerLog(String id0)
    { WriteTimerLog_58(id0); }

  public vtkLineIntegralConvolution2D() { super(); }

  public vtkLineIntegralConvolution2D(long id) { super(id); }
  public native long   VTKInit();

}
